Index: chrome/browser/resources/bookmark_manager/js/main.js |
diff --git a/chrome/browser/resources/bookmark_manager/js/main.js b/chrome/browser/resources/bookmark_manager/js/main.js |
index d01fca221906f05f8299c542c69c4ed94c507bab..de23c3a95e92266e45df74f8fd8a2827f8ea263a 100644 |
--- a/chrome/browser/resources/bookmark_manager/js/main.js |
+++ b/chrome/browser/resources/bookmark_manager/js/main.js |
@@ -459,9 +459,11 @@ function handleCanExecuteForDocument(e) { |
!isUnmodifiable(tree.getBookmarkNodeById(list.parentId)); |
break; |
case 'undo-command': |
// The global undo command has no visible UI, so always enable it, and |
// just make it a no-op if undo is not possible. |
- e.canExecute = true; |
+ e.canExecute = e.currentTarget.activeElement !== $('term'); |
break; |
default: |
canExecuteForList(e); |
@@ -459,9 +459,11 @@ function handleCanExecuteForDocument(e) { |
break; |
case 'undo-command': |
- // The global undo command has no visible UI, so always enable it, and |
+ // If the search box is active, pass the undo command through |
+ // (fixes http://crbug.com/278112). Otherwise, because |
+ // the global undo command has no visible UI, always enable it, and |
// just make it a no-op if undo is not possible. |